<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>FindRepeatsDialog</name>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="17"/>
        <source>Find repeats</source>
        <translation>Поиск повторов</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="27"/>
        <source>Repeat parameters</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="39"/>
        <source>Minimum repeat length</source>
        <translation>Мин длина повторов</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="74"/>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="239"/>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="299"/>
        <source>bp</source>
        <translation>нк</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="102"/>
        <source>Heuristic based selection of repeat length so the number of repeats in the sequence will not exceed 1000</source>
        <translation>Эвристический подбор длины повторов, с тем чтобы кол-во повторов в последовательности не превысило 1000</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="105"/>
        <source>1k</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="112"/>
        <source>Repeats  identity</source>
        <translation>Идентичность повторов</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="147"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="169"/>
        <source>Resets repeats identity to 100%</source>
        <translation>Сбросить к 100%</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="172"/>
        <source>100</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="211"/>
        <source>Minimum distance between repeats</source>
        <translation>Мин дистанция между повторами</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="258"/>
        <source>Maximum distance between repeats</source>
        <translation>Макс дистанция между повторами</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="318"/>
        <source>Custom algorithm</source>
        <translation>Выбранный алгоритм</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="345"/>
        <source>Search only repeats inside of annotated region</source>
        <translation>Искать повторы только внутри аннотированных регионов</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="387"/>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="436"/>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="485"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="394"/>
        <source>Search only repeats with annotated region inside</source>
        <translation>Искать только повторы с аннотированными регионами внутри</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="443"/>
        <source>Filter repeats with annotated region inside</source>
        <translation>Исключать повторы с аннотированными регионами</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="492"/>
        <source>Do not filter nested repeats</source>
        <translation>Не исключать вложенные повторы</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="512"/>
        <source>Search for inverted repeats</source>
        <translation>Искать инвертированные повторы</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="535"/>
        <source>Region to process</source>
        <translation>Регион поиска</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="541"/>
        <source>Whole sequence</source>
        <translation>Вся последовательность</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="564"/>
        <source>Selection</source>
        <translation>Выбранный</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="584"/>
        <source>Custom range</source>
        <translation>Указанный</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="610"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="681"/>
        <source>Start</source>
        <translation>Искать</translation>
    </message>
    <message>
        <location filename="../src/ui/FindRepeatsDialog.ui" line="691"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>FindTandemsDialog</name>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="17"/>
        <source>Find tandems</source>
        <translation>Поиск тандемов</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="27"/>
        <source>Repeat parameters</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="39"/>
        <source>Tandem preset</source>
        <translation>Предустановки тандемов</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="84"/>
        <source>Min period</source>
        <translation>Мин период</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="104"/>
        <location filename="../src/ui/FindTandemsDialog.ui" line="137"/>
        <source> n</source>
        <translation> н</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="117"/>
        <source>Max period</source>
        <translation>Макс период</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="153"/>
        <source>Repeats  identity</source>
        <translation>Идентичность повторов</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="197"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="213"/>
        <source>Algorithm</source>
        <translation>Алгоритм</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="243"/>
        <source>Minimum tandem size</source>
        <translation>Минимальный размер тандема</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="276"/>
        <source>Minimum repeat count</source>
        <translation>Минимальное число повторений</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="296"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="325"/>
        <source>Show overlapped tandems</source>
        <translation>Показать перекрывающиеся тандемы</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="335"/>
        <source>Region to process</source>
        <translation>Регион поиска</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="341"/>
        <source>Whole sequence</source>
        <translation>Вся последовательность</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="364"/>
        <source>Selection</source>
        <translation>Выбранный</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="384"/>
        <source>Custom range</source>
        <translation>Указанный</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="410"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="481"/>
        <source>Start</source>
        <translation>Искать</translation>
    </message>
    <message>
        <location filename="../src/ui/FindTandemsDialog.ui" line="491"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>GB2::ExactSizedTandemFinder</name>
    <message>
        <location filename="../src/RF_SArray_TandemFinder.h" line="126"/>
        <source>Find %1-period tandems</source>
        <translation>Поиск %1-периодных тандемов</translation>
    </message>
</context>
<context>
    <name>GB2::FindRepeatsDialog</name>
    <message>
        <location filename="../src/FindRepeatsDialog.cpp" line="63"/>
        <source>Auto</source>
        <translation>Автовыбор</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsDialog.cpp" line="64"/>
        <source>Suffix index</source>
        <translation>Суффиксный индекс</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsDialog.cpp" line="65"/>
        <source>Diagonals</source>
        <translation>Диагональный</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsDialog.cpp" line="194"/>
        <location filename="../src/FindRepeatsDialog.cpp" line="222"/>
        <source>Error</source>
        <translation>Проблема</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsDialog.cpp" line="194"/>
        <source>No annotations found: %1</source>
        <translation>Аннотации не найдены: %1</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsDialog.cpp" line="336"/>
        <source>Estimated repeats count: %1</source>
        <translation>Оценка возможного кол-ва результатов: %1</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsDialog.cpp" line="337"/>
        <source>Estimated repeats count hint is based on the active settings and random sequence model</source>
        <translation>Оценка основана на текущих параметрах поиска и модели случайной последовательности</translation>
    </message>
</context>
<context>
    <name>GB2::FindRepeatsTask</name>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="49"/>
        <source>Find repeats in a single sequence</source>
        <translation>Поиск повторов в одиночной последовательности</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="62"/>
        <source>Rev-complementing sequence</source>
        <translation>Перевод последовательности к комплементарной</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="87"/>
        <source>Searching repeats ...</source>
        <translation>Поиск повторов ...</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="101"/>
        <source>Filtering nested results</source>
        <translation>Фильтрация результатов</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="112"/>
        <source>Repeat search time %1 sec</source>
        <translation>Время поиска повторов: %1 сек</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="172"/>
        <source>Nested repeats filtering time %1 sec, results before: %2, filtered: %3, after %4</source>
        <translation>Время фильтрации вложенных повторов: %1 сек. Результатов было %2, отброшено %3, осталось %4</translation>
    </message>
</context>
<context>
    <name>GB2::FindRepeatsToAnnotationsTask</name>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="274"/>
        <source>Find repeats to annotations</source>
        <translation>Сохранение повторов в аннотации</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="293"/>
        <source>Found %1 repeat regions</source>
        <translation>Найдено повторов: %1</translation>
    </message>
</context>
<context>
    <name>GB2::FindTandemsDialog</name>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="57"/>
        <source>Suffix array</source>
        <translation>Суффиксный массив</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="58"/>
        <source>Suffix array (optimized)</source>
        <translation>Суффиксный массив (оптимизированный)</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="61"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="62"/>
        <source>Micro-satellites</source>
        <translation>Микро-сателлиты</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="63"/>
        <source>Mini-satellites</source>
        <translation>Мини-сателлиты</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="64"/>
        <source>Big-period tandems</source>
        <translation>Танемы с большим периодом</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="65"/>
        <source>Custom</source>
        <translation>Особые</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="181"/>
        <location filename="../src/FindTandemsDialog.cpp" line="206"/>
        <source>Error</source>
        <translation>Проблема</translation>
    </message>
    <message>
        <location filename="../src/FindTandemsDialog.cpp" line="181"/>
        <source>No annotations found: %1</source>
        <translation>Аннотации не найдены: %1</translation>
    </message>
    <message>
        <source>Estimated repeats count: %1</source>
        <translation type="obsolete">Оценка возможного кол-ва результатов: %1</translation>
    </message>
    <message>
        <source>Estimated repeats count hint is based on the active settings and random sequence model</source>
        <translation type="obsolete">Оценка основана на текущих параметрах поиска и модели случайной последовательности</translation>
    </message>
</context>
<context>
    <name>GB2::FindTandemsToAnnotationsTask</name>
    <message>
        <location filename="../src/RF_SArray_TandemFinder.cpp" line="18"/>
        <source>Find repeats to annotations</source>
        <translation>Сохранение повторов в аннотации</translation>
    </message>
    <message>
        <location filename="../src/RF_SArray_TandemFinder.cpp" line="37"/>
        <source>Found %1 repeat regions</source>
        <translation>Найдено повторов: %1</translation>
    </message>
</context>
<context>
    <name>GB2::LargeSizedTandemFinder</name>
    <message>
        <location filename="../src/RF_SArray_TandemFinder.h" line="172"/>
        <source>Find big-period tandems</source>
        <translation>Поиск тандемов с большим периодом</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::RepeatPrompter</name>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="116"/>
        <source> from %1</source>
        <translation> из %1</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="120"/>
        <source>inverted</source>
        <translation>инвертированные</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="120"/>
        <source>direct</source>
        <translation>прямые</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="122"/>
        <source>For each sequence&lt;u&gt;%1&lt;/u&gt;, find &lt;u&gt;%2&lt;/u&gt; repeats.&lt;br&gt;Detect &lt;u&gt;%3% identical&lt;/u&gt; repeats &lt;u&gt;not shorter than %4 bps&lt;/u&gt;.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
        <translation>Для каждой последовательности&lt;u&gt;%1&lt;/u&gt;, искать &lt;u&gt;%2&lt;/u&gt; повторы.&lt;br&gt;Учитывать &lt;u&gt;%3% идентичные&lt;/u&gt; повторы &lt;u&gt;не короче %4 нк&lt;/u&gt;.&lt;br&gt;Выдать список найденных регионов аннотированных как &lt;u&gt;%5&lt;/u&gt;.</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::RepeatWorker</name>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="47"/>
        <source>Input sequences</source>
        <translation>Входные последовательности</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="47"/>
        <source>A nucleotide sequence to search repeats in.</source>
        <translation>Входные нуклеотидные последовательности для поиска повторов.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="48"/>
        <source>Repeat annotations</source>
        <translation>Аннотированные повторы</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="48"/>
        <source>A set of annotations marking repeats found in the sequence.</source>
        <translation>Список аннотаций маркирующих найденные повторы.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="53"/>
        <source>Annotate as</source>
        <translation>Аннотации</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="53"/>
        <source>Name of the result annotations marking found repeats.</source>
        <translation>Имя аннотации для разметки найденных повторов.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="54"/>
        <source>Identity</source>
        <translation>Идентичность</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="54"/>
        <source>Repeats identity.</source>
        <translation>Идентичность повторов.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="55"/>
        <source>Min length</source>
        <translation>Мин длина</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="55"/>
        <source>Minimum length of repeats.</source>
        <translation>Мин длина повторов.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="56"/>
        <source>Min distance</source>
        <translation>Мин дистанция</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="56"/>
        <source>Minimum distance between repeats.</source>
        <translation>Мин дистанция между повторами.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="57"/>
        <source>Max distance</source>
        <translation>Макс дистанция</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="57"/>
        <source>Maximum distance between repeats.</source>
        <translation>Макс дистанция между повторами.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="58"/>
        <source>Inverted</source>
        <translation>Инвертированные</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="58"/>
        <source>Search for inverted repeats.</source>
        <translation>Искать инвертированные повторы.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="59"/>
        <source>Filter nested</source>
        <translation>Исключать вложенные</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="59"/>
        <source>Filter nested repeats.</source>
        <translation>Не исключать вложенные повторы.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="60"/>
        <source>Algorithm</source>
        <translation>Алгоритм</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="60"/>
        <source>Control over variations of algorithm.</source>
        <translation>Выбор алгоритма.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="61"/>
        <source>Parallel threads</source>
        <translation>Параллельные потоки</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="61"/>
        <source>Number of parallel threads used for the task.</source>
        <translation>Кол-во параллельных потоков для задачи.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="75"/>
        <source>Find repeats</source>
        <translation>Поиск повторов</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="76"/>
        <source>Finds repeats in each supplied sequence, stores found regions as annotations.</source>
        <translation>Ищет повторы в нуклеотидных последовательностях, выдаёт найденные регионы как аннотации.</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="81"/>
        <source> bp</source>
        <translation>нк</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="83"/>
        <source>Any</source>
        <translation>Не ограничивать</translation>
    </message>
    <message>
        <location filename="../src/RepeatWorker.cpp" line="169"/>
        <source>Found %1 repeats</source>
        <translation>Найдено повторов: %1</translation>
    </message>
</context>
<context>
    <name>GB2::RFAlgorithmBase</name>
    <message>
        <location filename="../src/RFBase.cpp" line="61"/>
        <source>Find repeats</source>
        <translation>Поиск повторов</translation>
    </message>
    <message>
        <location filename="../src/RFBase.cpp" line="105"/>
        <source>Repeat length is too large: %1, sequence size: %2</source>
        <translation>Длина повтора слишком велика: %1, размер последовательности: %2</translation>
    </message>
</context>
<context>
    <name>GB2::RFDiagonalWKSubtask</name>
    <message>
        <location filename="../src/RFDiagonal.cpp" line="34"/>
        <source>Find repeats subtask (diagonal)</source>
        <translation>Подзазадача поискв повторов (диагональный алгоритм)</translation>
    </message>
</context>
<context>
    <name>GB2::RFSArrayWKAlgorithm</name>
    <message>
        <location filename="../src/RFSArrayWK.cpp" line="34"/>
        <source>Memory allocation error, size: %1</source>
        <translation>Ошибка выделения памяти, размер: %1</translation>
    </message>
</context>
<context>
    <name>GB2::RFSArrayWKSubtask</name>
    <message>
        <location filename="../src/RFSArrayWK.cpp" line="168"/>
        <source>Find repeats subtask (suffixWK)</source>
        <translation>Подзазадача поискв повторов (суффиксный алгоритм)</translation>
    </message>
</context>
<context>
    <name>GB2::RFSArrayWSubtask</name>
    <message>
        <location filename="../src/RFSArray.cpp" line="320"/>
        <source>Find repeats subtask (suffix)</source>
        <translation>Подзазадача поискв повторов (суффиксный алгоритм)</translation>
    </message>
</context>
<context>
    <name>GB2::RepeatViewContext</name>
    <message>
        <location filename="../src/RepeatFinderPlugin.cpp" line="60"/>
        <source>Find Repeats</source>
        <translation>Поиск повторов</translation>
    </message>
    <message>
        <location filename="../src/RepeatFinderPlugin.cpp" line="63"/>
        <source>Find Tandems</source>
        <translation>Поиск тандемов</translation>
    </message>
</context>
<context>
    <name>GB2::RevComplSequenceTask</name>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="23"/>
        <source>Reverse complement sequence</source>
        <translation>Перевод последовательности к комплементарной</translation>
    </message>
    <message>
        <location filename="../src/FindRepeatsTask.cpp" line="30"/>
        <source>Can&apos;t find complement translation for alphabet: %1</source>
        <translation>Не найдена комплементарная трансляция для алфавита: %1</translation>
    </message>
</context>
<context>
    <name>GB2::TandemFinder</name>
    <message>
        <location filename="../src/RF_SArray_TandemFinder.cpp" line="112"/>
        <source>Find tandems finished %1</source>
        <translation>Поиск тандемов завершен %1</translation>
    </message>
    <message>
        <location filename="../src/RF_SArray_TandemFinder.cpp" line="72"/>
        <location filename="../src/RF_SArray_TandemFinder.cpp" line="105"/>
        <source>Find tandems</source>
        <translation>Поиск тандемов</translation>
    </message>
</context>
<context>
    <name>GB2::TandemFinder_Region</name>
    <message>
        <location filename="../src/RF_SArray_TandemFinder.h" line="91"/>
        <source>Find tandems in %1 region</source>
        <translation>Поиск тандемов в %1 регионе</translation>
    </message>
</context>
</TS>
